<?php
/**
 * Plugin Name: Word Count Sorter
 * Description: Adds a sortable Word Count column to the WordPress posts list.
 * Version: 1.0.0
 * Author: Md. Mizanul Kabir
 * License: GPL-2.0+
 * Tested up to: 6.7
 */

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Add word count column to the posts list
function wordcoso_add_column($columns) {
    $columns['word_count'] = esc_html__('Word Count', 'word-count-sorter');
    return $columns;
}
add_filter('manage_posts_columns', 'wordcoso_add_column');

// Display word count for each post
function wordcoso_display_column($column_name, $post_id) {
    if ($column_name == 'word_count') {
        // Get word count from the post content
        $post_content = get_post_field('post_content', $post_id);
        $word_count = str_word_count(wp_strip_all_tags($post_content)); // Get word count
        echo esc_html($word_count);

        // Save word count as a custom field
        update_post_meta($post_id, '_wordcoso_word_count', $word_count);
    }
}
add_action('manage_posts_custom_column', 'wordcoso_display_column', 10, 2);

// Make the word count column sortable
function wordcoso_sortable_column($columns) {
    $columns['word_count'] = 'word_count';
    return $columns;
}
add_filter('manage_edit-post_sortable_columns', 'wordcoso_sortable_column');

// Enable sorting by word count (ascending or descending based on user selection)
function wordcoso_sort_posts($query) {
    if (!is_admin() || !$query->is_main_query()) {
        return;
    }

    if ($query->get('orderby') == 'word_count') {
        $query->set('meta_key', '_wordcoso_word_count'); // Custom field key
        $query->set('orderby', 'meta_value_num'); // Sort by numeric value of the custom field
        
        $order = strtoupper($query->get('order'));
        if (!in_array($order, ['ASC', 'DESC'])) {
            $order = 'ASC'; // Default order
        }
        $query->set('order', $order);
    }
}
add_action('pre_get_posts', 'wordcoso_sort_posts');